@@ -111,10 +111,10 @@ class Album(MPTTModel):
             return self.cover
         elif getattr(self, '_cover', None):
             return self._cover
-        elif self.pictures.public():
+        try:
             self._cover = self.pictures.public().order_by('?')[0]
             return self._cover
-        else:
+        except IndexError:
             return None
 
     @property
